.. _simple_triangular_mesh_dataset:


Simple triangular mesh dataset
------------------------------

Triangulation of an unit hemisphere.

**Dataset characteristics:**

    :Number of vertices: 131
    :Number of triangles: 232
    :Creator: Uwe Graichen
    :Date: November, 2018
